ewa.rules.Not

Package ewa :: Module rules :: Class Not |
[hide private]
[frames] | no frames]

# Class Not

source code

    object --+
             |
     _jsonable --+
                 |
                Not

Instance Methods | [hide private]
__init__(self, matcher) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
match(self, target) | source code
Inherited from `_jsonable`: `to_jsondata` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, matcher) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)